@@ -87,8 +87,13 @@
   __attribute__((__noreturn__))
 #define G_GNUC_CONST                            \
   __attribute__((__const__))
+/* __attribute__((unused)) works with gcc3.3 but not g++3.3 */
+#if __GNUC__ == 3 && __GNUC_MINOR__ == 3 && !defined(__cplusplus)
 #define G_GNUC_UNUSED                           \
   __attribute__((__unused__))
+#else
+#define G_GNUC_UNUSED
+#endif
 #define G_GNUC_NO_INSTRUMENT			\
   __attribute__((__no_instrument_function__))
 #else   /* !__GNUC__ */
@@ -138,6 +143,10 @@
 #define G_STRINGIFY(macro_or_string)	G_STRINGIFY_ARG (macro_or_string)
 #define	G_STRINGIFY_ARG(contents)	#contents
 
+#define G_PASTE_ARGS(identifier1,identifier2) identifier1 ## identifier2
+#define G_PASTE(identifier1,identifier2)      G_PASTE_ARGS (identifier1, identifier2)
+#define G_STATIC_ASSERT(expr) typedef struct { char Compile_Time_Assertion[(expr) ? 1 : -1]; } G_PASTE (_GStaticAssert_, __LINE__)
+
 /* Provide a string identifying the current code position */
 #if defined(__GNUC__) && (__GNUC__ < 3) && !defined(__cplusplus)
 #  define G_STRLOC	__FILE__ ":" G_STRINGIFY (__LINE__) ":" __PRETTY_FUNCTION__ "()"
@@ -215,7 +224,7 @@
 
 #if defined(__GNUC__)  && __GNUC__ >= 4
 #  define G_STRUCT_OFFSET(struct_type, member) \
-      ((glong) __builtin_offsetof (struct_type, member))
+      ((glong) offsetof (struct_type, member))
 #else
 #  define G_STRUCT_OFFSET(struct_type, member)	\
       ((glong) ((guint8*) &((struct_type*) 0)->member))
